==> kdebase_3.3.2.orig.tar.gz: kdebase-3.3.2/kate/app/katemain.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __KATE_MAIN_H__
#define __KATE_MAIN_H__

#include <config.h>

#define KATE_VERSION "2.3.2"

class QComboBox;
class QDateTime;
class QEvent;
class QFileInfo;
class QGridLayout;
class QLabel;
class QListBox;
class QObject;
class QPixmap;
class QVBoxLayout;
class QString;
class QWidgetStack;

class KAction;
class KActionMenu;
class KConfig;
class KDirOperator;
class KEditToolbar;
class KFileViewItem;
class KHistoryCombo;
class KLineEdit;
class KListBox;
class KProcess;
class KPushButton;
class KRecentFilesAction;
class KSelectAction;
class KStatusBar;
class KToggleAction;
class KURL;
class KURLComboBox;

class KateApp;
class KateConfigDlg;
class KateConsole;
class KateDocManager;
class KateFileList;
class KateFileSelector;
class KateMainWindow;
class KatePluginIface;
class KatePluginManager;
class KateSidebar;
class KateViewManager;
class KateViewSpace;

#endif

==> kdebase_3.4.0.orig.tar.gz: kdebase-3.4.0/kate/app/katemain.h <==
/* This file is part of the KDE project
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __KATE_MAIN_H__
#define __KATE_MAIN_H__

#include <config.h>

#define KATE_VERSION "2.4"

class QComboBox;
class QDateTime;
class QEvent;
class QFileInfo;
class QGridLayout;
class QLabel;
class QListBox;
class QObject;
class QPixmap;
class QVBoxLayout;
class QString;
class QWidgetStack;

class KAction;
class KActionMenu;
class KConfig;
class KDirOperator;
class KEditToolbar;
class KFileViewItem;
class KHistoryCombo;
class KLineEdit;
class KListBox;
class KProcess;
class KPushButton;
class KRecentFilesAction;
class KSelectAction;
class KStatusBar;
class KToggleAction;
class KURL;
class KURLComboBox;

class KateApp;
class KateConfigDlg;
class KateConsole;
class KateDocManager;
class KateFileList;
class KateFileSelector;
class KateMainWindow;
class KatePluginIface;
class KatePluginManager;
class KateSidebar;
class KateViewManager;
class KateViewSpace;

#endif
